#
# spec file for package ibutils (Version 1.5.7)
#
# Copyright (c) 2010-2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define ibdm_major 1
%define extra_version -0.2.gbd7e502

Name:           ibutils
Summary:        OpenIB Mellanox InfiniBand Diagnostic Tools
Version:        1.5.7
Release:        6.2
License:        BSD-2-Clause or GPL-2.0
Group:          Productivity/Networking/Diagnostic
Source0:        http://www.openfarics.org/downloads/ibutils/%{name}-%{version}%{extra_version}.tar.gz
Source1:        ibutils-rpmlintrc
#PATCH-FIX-UPSTREAM Fix non-void functions returning no value
Patch1:         ibutils-1.2-retval.patch
#PATCH-FIX-UPSTREAM Extend the check to include tk 8.6
Patch2:         ibutils-tk-8.6.patch
#PATCH-FIX-UPSTREAM Prepare for autoreconf run
Patch4:         ibutils-autotools.patch
#PATCH-FIX-UPSTREAM Clean up code to reduce compiler warnings.
Patch5:         ibutils-code_cleanup.patch
Url:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++ libibverbs-devel opensm-devel tk-devel graphviz-tcl
BuildRequires:  automake autoconf libtool gawk fdupes swig
Requires:       graphviz-tcl

%description
The ibutils package provides a set of diagnostic tools that check the health
of an InfiniBand fabric.

Package components:
ibis:     IB interface - A TCL shell that provides interface for sending various
          MADs on the IB fabric. This is the component that actually accesses
          the IB Hardware.

ibdm:     IB Data Model - A library that provides IB fabric analysis.

ibmgtsim: An IB fabric simulator. Useful for developing IB tools.

ibdiag:   This package provides 3 tools which provide the user interface
          to activate the above functionality:
            - ibdiagnet:  Performs various quality and health checks on the IB
                          fabric.
            - ibdiagpath: Performs various fabric quality and health checks on
                          the given links and nodes in a specific path.
            - ibdiagui:   A GUI wrapper for the above tools.


%package        devel
Group:          Development/Libraries/C and C++
Summary:        OpenIB Mellanox InfiniBand Diagnostic Tools
Requires:       %{name} = %{version}
Requires:       libibdm%{ibdm_major} = %{version}


%description    devel
ibutils provides IB network and path diagnostics.

%package        devel-static
Group:          Development/Libraries/C and C++
Summary:        OpenIB Mellanox InfiniBand Diagnostic Tools - static library
Requires:       %{name} = %{version} ibutils-devel = %{version}

%description devel-static
These are the static libraries for the OpenIB Mellanox InfiniBand Diagnostic
Tools.

%package     -n libibdm%{ibdm_major}
Group:          System/Libraries
Summary:        Shared libraries for ibutils

%description -n libibdm%{ibdm_major}
This package contains shared libraries for the IB utils.

%prep
%setup -q
%patch1
%patch2
%patch4
%patch5

%build
autoreconf -fi
./autogen.sh
export CFLAGS="%{optflags} -Wno-unused-but-set-variable"
export CXXFLAGS="%{optflags} -Wno-unused-but-set-variable"
%configure --with-graphviz-lib=%{_libdir}
#ibutil is missing some dependencies in its makefile so don't build in multiple jobs
#make %%{?_smp_mflags}
make 

%install
export NO_BRP_TCL_INDEX_CHECK=true
%makeinstall 
# It's empty, so just get rid of it
rm -f %{buildroot}%{_libdir}/libibdmcom.la
%fdupes -s %{buildroot}%{_libdir}

%post -n libibdm%{ibdm_major} -p /sbin/ldconfig
%postun -n libibdm%{ibdm_major} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc COPYING
%_bindir/*
%_libdir/ibdiagnet%{version}
%_libdir/ibdiagpath%{version}
%_libdir/ibdiagui%{version}
%_libdir/ibdm%{version}
%_libdir/ibis%{version}
%_mandir/man1/*

%files -n libibdm%{ibdm_major}
%defattr(-, root, root)
%_libdir/libibdm.so.*
%_libdir/libibdmcom.so.*
%_libdir/libibsysapi.so.*

%files devel
%defattr(-, root, root)
%_includedir/ibdm
%_libdir/libibdm.so
%_libdir/libibdmcom.so
%_libdir/libibsysapi.so

%files devel-static
%defattr(-, root, root)
%_libdir/*.la
%_libdir/*.a

%changelog
* Thu Aug 21 2014 pth@suse.de
- Ibutils Makefiles are missing dependencies so successfull builds
  depend on timing so build in single job until fixed.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue May 13 2014 pth@suse.de
- Update to 1.5.7-0.2.gbd7e502 from OFED 3.12 RC2.
  No change log present.
- Added the fix for two cases of forbidden implicit const removal
  to ibutils-code_cleanup.patch.
- Remove ibutils-add_shebang.patch as the file it pathed doesn't
  exist anymore.
* Wed Mar  5 2014 pth@suse.de
- Add COPYING to package docs.
* Fri Jan 17 2014 pth@suse.de
- Update to OFED 3.12 daily snapshot
- Use spdx.org format for license specification
* Wed Aug 28 2013 pth@suse.de
- Add ibutils-tk-8.6.patch to include tk 8.6 in the check for accetable
  tk versions.
- Add ibutils-add_shebang.patch to add a shebang to git_version.tcl
  which is installed in _bindir.
- Run fdupes to eleminate file duplication.
- Add a rpmlintrc file to silence useless warnings.
- Add ibutils-autotools.patch to modify the neccessary files
  so that autoreconf can be called.
- (Build)Require graphviz-tcl as ibdiag won't work correctly without
  the graphviz tcl plugin.
* Tue Sep 11 2012 pth@suse.de
- Update to 1.5.7-0.1.g05a9d1a from OFED 1.5.4.1:
  New Features:
  * Added scripts that convert OSM dump files for ibdmchk
  ibutils: added support for GUIDInfo MAD in ibis and simulator
  Major Bugs Fixed:
  * ibmgtsim: fixed various bugs with running simulations
  * ibutils: fixed rpmbuild with and w/o ibmgtsim
  Known Issues:
  * Ibdiagnet "-wt" option may generate a bad topology file when
    running on a cluster that contains complex switch systems.
  * ibutils works only partially on any distro with TCL 8.5.
    ibdiagnet/ibdiagpath/ibis don't work with TCL 8.5 due to a change
    in TCL behavior: the built-in TCL function "dump" on TCL 8.5
    always includes field names.
    Until the fix, any user script that uses ibis needs to be fixed
    in order to function correctly on TCL 8.5
- Adapt the patch.
- Package static library in a devel-static package.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Tue May 25 2010 jjolly@novell.com
- Updated to v1.5.4 from OFED 1.5.1
- Removed patch for libreplace
- Updated the retval patch to include a fix to CredLoops.cpp
* Fri May 14 2010 jjolly@novell.com
- Updated the ibutils tarball to the one found in the OFED 1.4.2
  release.  There is no version change as the ibutils package in
  OFED changed, but did not change version numbers.
* Thu Oct 16 2008 jjolly@suse.de
- Updated with version from OFED 1.3.1 release
* Fri Feb 29 2008 jjolly@suse.de
- Updated with release from OFED 1.3 GA
* Tue Jan 29 2008 jjolly@suse.de
- Updated with release from OFED 1.3 rc2 (still v1.2)
* Mon Jul  9 2007 hvogel@suse.de
- Use correct version number
* Wed Jul  4 2007 hvogel@suse.de
- add GPL COPYING file [#288790]
* Mon Jul  2 2007 hvogel@suse.de
- Update to the OFED 1.2 release
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.0
